==> zio-aws-emr_2.12-5.17.196.1-sources.jar: zio/aws/emr/model/Step.scala <==
package zio.aws.emr.model
import zio.aws.emr.model.primitives.StepId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class Step(
    id: Optional[StepId] = Optional.Absent,
    name: Optional[String] = Optional.Absent,
    config: Optional[zio.aws.emr.model.HadoopStepConfig] = Optional.Absent,
    actionOnFailure: Optional[zio.aws.emr.model.ActionOnFailure] =
      Optional.Absent,
    status: Optional[zio.aws.emr.model.StepStatus] = Optional.Absent
) {
  def buildAwsValue(): software.amazon.awssdk.services.emr.model.Step = {
    import Step.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.emr.model.Step
      .builder()
      .optionallyWith(id.map(value => StepId.unwrap(value): java.lang.String))(
        _.id
      )
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(config.map(value => value.buildAwsValue()))(_.config)
      .optionallyWith(actionOnFailure.map(value => value.unwrap))(
        _.actionOnFailure
      )
      .optionallyWith(status.map(value => value.buildAwsValue()))(_.status)
      .build()
  }
  def asReadOnly: zio.aws.emr.model.Step.ReadOnly =
    zio.aws.emr.model.Step.wrap(buildAwsValue())
}
object Step {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.emr.model.Step] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.emr.model.Step = zio.aws.emr.model.Step(
      id.map(value => value),
      name.map(value => value),
      config.map(value => value.asEditable),
      actionOnFailure.map(value => value),
      status.map(value => value.asEditable)
    )
    def id: Optional[StepId]
    def name: Optional[String]
    def config: Optional[zio.aws.emr.model.HadoopStepConfig.ReadOnly]
    def actionOnFailure: Optional[zio.aws.emr.model.ActionOnFailure]
    def status: Optional[zio.aws.emr.model.StepStatus.ReadOnly]
    def getId: ZIO[Any, AwsError, StepId] = AwsError.unwrapOptionField("id", id)
    def getName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("name", name)
    def getConfig
        : ZIO[Any, AwsError, zio.aws.emr.model.HadoopStepConfig.ReadOnly] =
      AwsError.unwrapOptionField("config", config)
    def getActionOnFailure
        : ZIO[Any, AwsError, zio.aws.emr.model.ActionOnFailure] =
      AwsError.unwrapOptionField("actionOnFailure", actionOnFailure)
    def getStatus: ZIO[Any, AwsError, zio.aws.emr.model.StepStatus.ReadOnly] =
      AwsError.unwrapOptionField("status", status)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.emr.model.Step
  ) extends zio.aws.emr.model.Step.ReadOnly {
    override val id: Optional[StepId] = zio.aws.core.internal
      .optionalFromNullable(impl.id())
      .map(value => zio.aws.emr.model.primitives.StepId(value))
    override val name: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => value: String)
    override val config: Optional[zio.aws.emr.model.HadoopStepConfig.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.config())
        .map(value => zio.aws.emr.model.HadoopStepConfig.wrap(value))
    override val actionOnFailure: Optional[zio.aws.emr.model.ActionOnFailure] =
      zio.aws.core.internal
        .optionalFromNullable(impl.actionOnFailure())
        .map(value => zio.aws.emr.model.ActionOnFailure.wrap(value))
    override val status: Optional[zio.aws.emr.model.StepStatus.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value => zio.aws.emr.model.StepStatus.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.emr.model.Step
  ): zio.aws.emr.model.Step.ReadOnly = new Wrapper(impl)
}

==> zio-aws-emr_2.13-5.17.125.1-sources.jar: zio/aws/emr/model/Step.scala <==
package zio.aws.emr.model
import zio.aws.emr.model.primitives.StepId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class Step(
    id: Option[StepId] = None,
    name: Option[String] = None,
    config: Option[zio.aws.emr.model.HadoopStepConfig] = None,
    actionOnFailure: Option[zio.aws.emr.model.ActionOnFailure] = None,
    status: Option[zio.aws.emr.model.StepStatus] = None
) {
  def buildAwsValue(): software.amazon.awssdk.services.emr.model.Step = {
    import Step.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.emr.model.Step
      .builder()
      .optionallyWith(id.map(value => StepId.unwrap(value): java.lang.String))(
        _.id
      )
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(config.map(value => value.buildAwsValue()))(_.config)
      .optionallyWith(actionOnFailure.map(value => value.unwrap))(
        _.actionOnFailure
      )
      .optionallyWith(status.map(value => value.buildAwsValue()))(_.status)
      .build()
  }
  def asReadOnly: zio.aws.emr.model.Step.ReadOnly =
    zio.aws.emr.model.Step.wrap(buildAwsValue())
}
object Step {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.emr.model.Step] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.emr.model.Step = zio.aws.emr.model.Step(
      id.map(value => value),
      name.map(value => value),
      config.map(value => value.asEditable),
      actionOnFailure.map(value => value),
      status.map(value => value.asEditable)
    )
    def id: Option[StepId]
    def name: Option[String]
    def config: Option[zio.aws.emr.model.HadoopStepConfig.ReadOnly]
    def actionOnFailure: Option[zio.aws.emr.model.ActionOnFailure]
    def status: Option[zio.aws.emr.model.StepStatus.ReadOnly]
    def getId: ZIO[Any, AwsError, StepId] = AwsError.unwrapOptionField("id", id)
    def getName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("name", name)
    def getConfig
        : ZIO[Any, AwsError, zio.aws.emr.model.HadoopStepConfig.ReadOnly] =
      AwsError.unwrapOptionField("config", config)
    def getActionOnFailure
        : ZIO[Any, AwsError, zio.aws.emr.model.ActionOnFailure] =
      AwsError.unwrapOptionField("actionOnFailure", actionOnFailure)
    def getStatus: ZIO[Any, AwsError, zio.aws.emr.model.StepStatus.ReadOnly] =
      AwsError.unwrapOptionField("status", status)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.emr.model.Step
  ) extends zio.aws.emr.model.Step.ReadOnly {
    override val id: Option[StepId] = scala
      .Option(impl.id())
      .map(value => zio.aws.emr.model.primitives.StepId(value))
    override val name: Option[String] =
      scala.Option(impl.name()).map(value => value: String)
    override val config: Option[zio.aws.emr.model.HadoopStepConfig.ReadOnly] =
      scala
        .Option(impl.config())
        .map(value => zio.aws.emr.model.HadoopStepConfig.wrap(value))
    override val actionOnFailure: Option[zio.aws.emr.model.ActionOnFailure] =
      scala
        .Option(impl.actionOnFailure())
        .map(value => zio.aws.emr.model.ActionOnFailure.wrap(value))
    override val status: Option[zio.aws.emr.model.StepStatus.ReadOnly] = scala
      .Option(impl.status())
      .map(value => zio.aws.emr.model.StepStatus.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.emr.model.Step
  ): zio.aws.emr.model.Step.ReadOnly = new Wrapper(impl)
}
